Installation — asyncpool 1.0.1 documentation

# Installation

## Python Version

Asyncpool supports Python3.5+.

## Dependencies

### Required

- None

### Optional

- uvloop is a fast, drop-in replacement of the built-in asyncio event loop.

## Install Asyncpool

### For General Users

Use the package manager pip or pipenv to install asyncpool.

With pip:

    $ pip install asyncpool

Or with pipenv:

    $ pipenv install asyncpool

#### Install Optional Dependencies

Simply add a suffix:

    $ pip install asyncpool[uvloop]

### For Contributors

Install with pipenv(recommand if you want to build docs):

    git clone https://github.com/lunluen/asyncpool.git
    cd asyncpool
    pipenv install --dev

or with setuptools:

    git clone https://github.com/lunluen/asyncpool.git
    cd asyncpool
    python setup.py develop